diff --git a/core/lib/Drupal/Component/Utility/Random.php b/core/lib/Drupal/Component/Utility/Random.php
index 799520a78393f2bd3b08614067ee19c439021924..a23fd11a164e718133ea386346d3baad3ba7bc75 100644
--- a/core/lib/Drupal/Component/Utility/Random.php
+++ b/core/lib/Drupal/Component/Utility/Random.php
@@ -319,9 +319,9 @@ public function paragraphs($paragraph_count = 12) {
    * @param string $destination
    *   The absolute file path where the image should be stored.
    * @param string $min_resolution
-   *   The minimum resolution for the image. For example, '400x300'.
+   *   The minimum dimensions for the image. For example, '400x300'.
    * @param string $max_resolution
-   *   The maximum resolution for the image. For example, '800x600'.
+   *   The maximum dimensions for the image. For example, '800x600'.
    *
    * @return string
    *   Path to image file.
diff --git a/core/modules/image/config/schema/image.schema.yml b/core/modules/image/config/schema/image.schema.yml
index 5a0a9ce474f6122dd970d8f66dbf357c60fc7116..d3c9e980f0cf0fa95f11d7c723082c4f78078d86 100644
--- a/core/modules/image/config/schema/image.schema.yml
+++ b/core/modules/image/config/schema/image.schema.yml
@@ -108,10 +108,10 @@ field.field_settings.image:
   mapping:
     max_resolution:
       type: string
-      label: 'Maximum image resolution'
+      label: 'Maximum image dimensions'
     min_resolution:
       type: string
-      label: 'Minimum image resolution'
+      label: 'Minimum image dimensions'
     alt_field:
       type: boolean
       label: 'Enable Alt field'
diff --git a/core/modules/image/image.module b/core/modules/image/image.module
index 807b58c33a43fd70b6f8f89b0eed29ffa4a72f4c..eb407dcfd162a9c81ee3b9bbc59b3c682d0592c0 100644
--- a/core/modules/image/image.module
+++ b/core/modules/image/image.module
@@ -37,11 +37,11 @@ function image_help($route_name, RouteMatchInterface $route_match) {
       $output .= '<dt>' . t('Naming image styles') . '</dt>';
       $output .= '<dd>' . t('When you define an image style, you will need to choose a displayed name and a machine name. The displayed name is shown in administrative pages, and the machine name is used to generate the URL for accessing an image processed in that style. There are two common approaches to naming image styles: either based on the effects being applied (for example, <em>Square 85x85</em>), or based on where you plan to use it (for example, <em>Profile picture</em>).') . '</dd>';
       $output .= '<dt>' . t('Configuring image fields') . '</dt>';
-      $output .= '<dd>' . t('A few of the settings for image fields are defined once when you create the field and cannot be changed later; these include the choice of public or private file storage and the number of images that can be stored in the field. The rest of the settings can be edited later; these settings include the field label, help text, allowed file extensions, image resolution restrictions, and the subdirectory in the public or private file storage where the images will be stored. The editable settings can also have different values for different entity sub-types; for instance, if your image field is used on both Page and Article content types, you can store the files in a different subdirectory for the two content types.') . '</dd>';
+      $output .= '<dd>' . t('A few of the settings for image fields are defined once when you create the field and cannot be changed later; these include the choice of public or private file storage and the number of images that can be stored in the field. The rest of the settings can be edited later; these settings include the field label, help text, allowed file extensions, image dimensions restrictions, and the subdirectory in the public or private file storage where the images will be stored. The editable settings can also have different values for different entity sub-types; for instance, if your image field is used on both Page and Article content types, you can store the files in a different subdirectory for the two content types.') . '</dd>';
       $output .= '<dd>' . t('For accessibility and search engine optimization, all images that convey meaning on websites should have alternate text. Drupal also allows entry of title text for images, but it can lead to confusion for screen reader users and its use is not recommended. Image fields can be configured so that alternate and title text fields are enabled or disabled; if enabled, the fields can be set to be required. The recommended setting is to enable and require alternate text and disable title text.') . '</dd>';
       $output .= '<dd>' . t('When you create an image field, you will need to choose whether the uploaded images will be stored in the public or private file directory defined in your settings.php file and shown on the <a href=":file-system">File system page</a>. This choice cannot be changed later. You can also configure your field to store files in a subdirectory of the public or private directory; this setting can be changed later and can be different for each entity sub-type using the field. For more information on file storage, see the <a href=":system-help">System module help page</a>.', [':file-system' => Url::fromRoute('system.file_system_settings')->toString(), ':system-help' => Url::fromRoute('help.page', ['name' => 'system'])->toString()]) . '</dd>';
       $output .= '<dd>' . t('The maximum file size that can be uploaded is limited by PHP settings of the server, but you can restrict it further by configuring a <em>Maximum upload size</em> in the field settings (this setting can be changed later). The maximum file size, either from PHP server settings or field configuration, is automatically displayed to users in the help text of the image field.') . '</dd>';
-      $output .= '<dd>' . t('You can also configure a minimum and/or maximum resolution for uploaded images. Images that are too small will be rejected. Images that are to large will be resized. During the resizing the <a href="http://wikipedia.org/wiki/Exchangeable_image_file_format">EXIF data</a> in the image will be lost.') . '</dd>';
+      $output .= '<dd>' . t('You can also configure a minimum and/or maximum dimensions for uploaded images. Images that are too small will be rejected. Images that are to large will be resized. During the resizing the <a href="http://wikipedia.org/wiki/Exchangeable_image_file_format">EXIF data</a> in the image will be lost.') . '</dd>';
       $output .= '<dd>' . t('You can also configure a default image that will be used if no image is uploaded in an image field. This default can be defined for all instances of the field in the field storage settings when you create a field, and the setting can be overridden for each entity sub-type that uses the field.') . '</dd>';
       $output .= '<dt>' . t('Configuring displays and form displays') . '</dt>';
       $output .= '<dd>' . t('On the <em>Manage display</em> page, you can choose the image formatter, which determines the image style used to display the image in each display mode and whether or not to display the image as a link. On the <em>Manage form display</em> page, you can configure the image upload widget, including setting the preview image style shown on the entity edit form.') . '</dd>';
diff --git a/core/modules/image/src/Plugin/Field/FieldWidget/ImageWidget.php b/core/modules/image/src/Plugin/Field/FieldWidget/ImageWidget.php
index 81aca6f66a5ae6522b0f0879efe34772f92babc3..8f7505c33c15bf238146b760c157dd221afec64e 100644
--- a/core/modules/image/src/Plugin/Field/FieldWidget/ImageWidget.php
+++ b/core/modules/image/src/Plugin/Field/FieldWidget/ImageWidget.php
@@ -148,7 +148,7 @@ public function formElement(FieldItemListInterface $items, $delta, array $elemen
     // Add image validation.
     $element['#upload_validators']['FileIsImage'] = [];
 
-    // Add upload resolution validation.
+    // Add upload dimensions validation.
     if ($field_settings['max_resolution'] || $field_settings['min_resolution']) {
       $element['#upload_validators']['FileImageDimensions'] = [
         'maxDimensions' => $field_settings['max_resolution'],
diff --git a/core/modules/image/tests/src/Functional/ImageFieldDisplayTest.php b/core/modules/image/tests/src/Functional/ImageFieldDisplayTest.php
index 3ce49168a630f3b46da2f5fdc945cda9c4880ade..6517f377319fe86a55c8df5c31b2a27068cfc313 100644
--- a/core/modules/image/tests/src/Functional/ImageFieldDisplayTest.php
+++ b/core/modules/image/tests/src/Functional/ImageFieldDisplayTest.php
@@ -260,7 +260,7 @@ public function testImageFieldSettings() {
     ];
     $field = $this->createImageField($field_name, 'article', [], $field_settings, $widget_settings);
 
-    // Verify that the min/max resolution set on the field are properly
+    // Verify that the min/max dimensions set on the field are properly
     // extracted, and displayed, on the image field's configuration form.
     $this->drupalGet('admin/structure/types/manage/article/fields/' . $field->id());
     $this->assertSession()->fieldValueEquals('settings[max_resolution][x]', '100');
diff --git a/core/modules/image/tests/src/Functional/ImageFieldValidateTest.php b/core/modules/image/tests/src/Functional/ImageFieldValidateTest.php
index 3228669215a87196edcbecc863f3366cff854250..b426730dd7f126d793b8ad29aefe50c2b2dd5f3b 100644
--- a/core/modules/image/tests/src/Functional/ImageFieldValidateTest.php
+++ b/core/modules/image/tests/src/Functional/ImageFieldValidateTest.php
@@ -6,7 +6,7 @@
 use Drupal\Tests\TestFileCreationTrait;
 
 /**
- * Tests validation functions such as min/max resolution.
+ * Tests validation functions such as min/max dimensions.
  *
  * @group image
  */
@@ -85,7 +85,7 @@ public function testValid() {
   }
 
   /**
-   * Tests min/max resolution settings.
+   * Tests min/max dimensions settings.
    */
   public function testResolution() {
     $field_names = [
@@ -265,9 +265,9 @@ public function providerTestEmpty() {
    * Returns field settings.
    *
    * @param int[] $min_resolution
-   *   The minimum width and height resolution setting.
+   *   The minimum width and height setting.
    * @param int[] $max_resolution
-   *   The maximum width and height resolution setting.
+   *   The maximum width and height setting.
    *
    * @return array
    */
diff --git a/core/modules/image/tests/src/FunctionalJavascript/ImageFieldValidateTest.php b/core/modules/image/tests/src/FunctionalJavascript/ImageFieldValidateTest.php
index 1bfe3e692e11fc744823f798269301b978d3fe3e..f26f32643ca0efe22c7164f634da5ae1932015a2 100644
--- a/core/modules/image/tests/src/FunctionalJavascript/ImageFieldValidateTest.php
+++ b/core/modules/image/tests/src/FunctionalJavascript/ImageFieldValidateTest.php
@@ -6,7 +6,7 @@
 use Drupal\field\Entity\FieldConfig;
 
 /**
- * Tests validation functions such as min/max resolution.
+ * Tests validation functions such as min/max dimensions.
  *
  * @group image
  */
diff --git a/core/modules/image/tests/src/Kernel/ImageItemTest.php b/core/modules/image/tests/src/Kernel/ImageItemTest.php
index fc0699aaf6a8aa5ae57ba4353d48cc1e570ffebe..2938bb9fa24351681902ee8e28e52151b043d664 100644
--- a/core/modules/image/tests/src/Kernel/ImageItemTest.php
+++ b/core/modules/image/tests/src/Kernel/ImageItemTest.php
@@ -155,17 +155,17 @@ public function testImageItem() {
   }
 
   /**
-   * Tests generateSampleItems() method under different resolutions.
+   * Tests generateSampleItems() method under different dimensions.
    */
   public function testImageItemSampleValueGeneration() {
 
-    // Default behavior. No resolution configuration.
+    // Default behavior. No dimensions configuration.
     $entity = EntityTest::create();
     $entity->image_test->generateSampleItems();
     $this->entityValidateAndSave($entity);
     $this->assertEquals('image/jpeg', $entity->image_test->entity->get('filemime')->value);
 
-    // Max resolution bigger than 600x600.
+    // Max dimensions bigger than 600x600.
     $entity->image_test_generation->generateSampleItems();
     $this->entityValidateAndSave($entity);
     $imageItem = $entity->image_test_generation->first()->getValue();
diff --git a/core/modules/user/src/Plugin/migrate/source/UserPictureInstance.php b/core/modules/user/src/Plugin/migrate/source/UserPictureInstance.php
index cd4f0b00ac1c125e7c153bbb1b20a8a9424d8612..89383f5dc7d905a864410cdf5d7718574be16faa 100644
--- a/core/modules/user/src/Plugin/migrate/source/UserPictureInstance.php
+++ b/core/modules/user/src/Plugin/migrate/source/UserPictureInstance.php
@@ -45,7 +45,7 @@ public function fields() {
     return [
       'file_directory' => 'The directory to store images..',
       'max_filesize' => 'The maximum allowed file size in KBs.',
-      'max_resolution' => "The maximum resolution.",
+      'max_resolution' => "The maximum dimensions.",
     ];
   }
diff --git a/core/modules/file/tests/src/Kernel/LegacyValidatorTest.php b/core/modules/file/tests/src/Kernel/LegacyValidatorTest.php
index 02ba7248996a057e8c67c3d2518e56b6ce727beb..150438c41f23a0d150d8fe686cdf24c84db8c232 100644
--- a/core/modules/file/tests/src/Kernel/LegacyValidatorTest.php
+++ b/core/modules/file/tests/src/Kernel/LegacyValidatorTest.php
@@ -156,7 +156,7 @@ public function testFileValidateIsImage() {
   }
 
   /**
    * This ensures the resolution of a specific file is within bounds.
    *
    * The image will be resized if it's too large.
    */
@@ -166,11 +166,11 @@ public function testFileValidateImageResolution() {
     $errors = file_validate_image_resolution($this->nonImage);
     $this->assertCount(0, $errors, 'Should not get any errors for a non-image file.');
     $errors = file_validate_image_resolution($this->nonImage, '50x50', '100x100');
-    $this->assertCount(0, $errors, 'Do not check the resolution on non files.');
+    $this->assertCount(0, $errors, 'Do not check the dimensions on non files.');
 
     // Minimum size.
     $errors = file_validate_image_resolution($this->image);
-    $this->assertCount(0, $errors, 'No errors for an image when there is no minimum or maximum resolution.');
+    $this->assertCount(0, $errors, 'No errors for an image when there is no minimum or maximum dimensions.');
     $errors = file_validate_image_resolution($this->image, 0, '200x1');
     $this->assertCount(1, $errors, 'Got an error for an image that was not wide enough.');
     $errors = file_validate_image_resolution($this->image, 0, '1x200');
@@ -156,7 +156,7 @@ public function testFileValidateIsImage() {
 
   /**
-   * This ensures the resolution of a specific file is within bounds.
+   * This ensures the dimensions of a specific file is within bounds.
    *
    * The image will be resized if it's too large.
diff --git a/core/modules/file/tests/src/Kernel/Plugin/Validation/Constraint/FileImageDimensionsConstraintValidatorTest.php b/core/modules/file/tests/src/Kernel/Plugin/Validation/Constraint/FileImageDimensionsConstraintValidatorTest.php
index 37594eac24bd2a768d25b09e05f001dc819cc168..3675ff79f53a50c0e1c8f6552e243df77a195826 100644
--- a/core/modules/file/tests/src/Kernel/Plugin/Validation/Constraint/FileImageDimensionsConstraintValidatorTest.php
+++ b/core/modules/file/tests/src/Kernel/Plugin/Validation/Constraint/FileImageDimensionsConstraintValidatorTest.php
@@ -48,7 +48,7 @@ protected function setUp(): void {
   }
 
   /**
    * This ensures the resolution of a specific file is within bounds.
    *
    * The image will be resized if it's too large.
    *
@@ -66,7 +66,7 @@ public function testFileValidateImageResolution() {
       ],
     ];
     $violations = $this->validator->validate($this->nonImage, $validators);
-    $this->assertCount(0, $violations, 'Do not check the resolution on non files.');
+    $this->assertCount(0, $violations, 'Do not check the dimensions on non files.');
 
     // Minimum size.
     $validators = ['FileImageDimensions' => []];
@@ -48,7 +48,7 @@ protected function setUp(): void {
 
   /**
-   * This ensures the resolution of a specific file is within bounds.
+   * This ensures the dimensions of a specific file is within bounds.
    *
    * The image will be resized if it's too large.
diff --git a/core/modules/image/src/Plugin/Field/FieldType/ImageItem.php b/core/modules/image/src/Plugin/Field/FieldType/ImageItem.php
index 2d29c34ba95b48b2491cfa6ee6a7cdaf02993d9a..7f96744c5ff6bc4abdb10849d18b0a1617a3d7d3 100644
--- a/core/modules/image/src/Plugin/Field/FieldType/ImageItem.php
+++ b/core/modules/image/src/Plugin/Field/FieldType/ImageItem.php
@@ -23,8 +23,8 @@
  *   label = @Translation("Image"),
  *   description = {
  *     @Translation("For uploading images"),
  *     @Translation("Allows a user to upload an image with configurable extensions, image resolutions, upload size"),
  *     @Translation("Can be configured with options such as allowed file extensions, maximum upload size and image resolution minimums/maximums"),
  *   },
  *   category = "file_upload",
  *   default_widget = "image_image",
@@ -208,11 +208,11 @@ public function fieldSettingsForm(array $form, FormStateInterface $form_state) {
 
     $settings = $this->getSettings();
 
     // Add maximum and minimum resolution settings.
     $max_resolution = explode('x', $settings['max_resolution']) + ['', ''];
     $element['max_resolution'] = [
       '#type' => 'item',
-      '#title' => $this->t('Maximum image resolution'),
+      '#title' => $this->t('Maximum image dimensions'),
       '#element_validate' => [[static::class, 'validateResolution']],
       '#weight' => 4.1,
       '#description' => $this->t('The maximum allowed image size expressed as WIDTH×HEIGHT (e.g. 640×480). Leave blank for no restriction. If a larger image is uploaded, it will be resized to reflect the given width and height. Resizing images on upload will cause the loss of <a href="http://wikipedia.org/wiki/Exchangeable_image_file_format">EXIF data</a> in the image.'),
@@ -239,7 +239,7 @@ public function fieldSettingsForm(array $form, FormStateInterface $form_state) {
     $min_resolution = explode('x', $settings['min_resolution']) + ['', ''];
     $element['min_resolution'] = [
       '#type' => 'item',
-      '#title' => $this->t('Minimum image resolution'),
+      '#title' => $this->t('Minimum image dimensions'),
       '#element_validate' => [[static::class, 'validateResolution']],
       '#weight' => 4.2,
       '#description' => $this->t('The minimum allowed image size expressed as WIDTH×HEIGHT (e.g. 640×480). Leave blank for no restriction. If a smaller image is uploaded, it will be rejected.'),
@@ -406,7 +406,7 @@ public static function generateSampleValue(FieldDefinitionInterface $field_defin
   }
 
   /**
    * Element validate function for resolution fields.
    */
   public static function validateResolution($element, FormStateInterface $form_state) {
     if (!empty($element['x']['#value']) || !empty($element['y']['#value'])) {
@@ -23,8 +23,8 @@
  *   description = {
  *     @Translation("For uploading images"),
- *     @Translation("Allows a user to upload an image with configurable extensions, image resolutions, upload size"),
- *     @Translation("Can be configured with options such as allowed file extensions, maximum upload size and image resolution minimums/maximums"),
+ *     @Translation("Allows a user to upload an image with configurable extensions, image dimensions, upload size"),
+ *     @Translation("Can be configured with options such as allowed file extensions, maximum upload size and image dimensions minimums/maximums"),
  *   },
  *   category = "file_upload",
@@ -208,11 +208,11 @@ public function fieldSettingsForm(array $form, FormStateInterface $form_state) {
     $settings = $this->getSettings();
 
-    // Add maximum and minimum resolution settings.
+    // Add maximum and minimum dimensions settings.
     $max_resolution = explode('x', $settings['max_resolution']) + ['', ''];
     $element['max_resolution'] = [
@@ -406,7 +406,7 @@ public static function generateSampleValue(FieldDefinitionInterface $field_defin
 
   /**
-   * Element validate function for resolution fields.
+   * Element validate function for dimensions fields.
    */
   public static function validateResolution($element, FormStateInterface $form_state) {